Apply .clangformat to all repo source files

Change-Id: I7e79c6058f0303f9a98911e3b7dd2e8596079344


[ROCm/hip commit: 1ba06f63c4]
This commit is contained in:
Maneesh Gupta
2018-03-12 11:29:03 +05:30
parent 52506ef382
commit 4f42ee762d
293 changed files with 43980 additions and 45830 deletions
+7 -7
View File
@@ -25,20 +25,20 @@ THE SOFTWARE.
#include "test_common.h"
#include <stdio.h>
#define ITER 1<<20
#define SIZE 1024*1024*sizeof(int)
#define ITER 1 << 20
#define SIZE 1024 * 1024 * sizeof(int)
__global__ void Iter(hipLaunchParm lp, int *Ad){
__global__ void Iter(hipLaunchParm lp, int* Ad) {
int tx = threadIdx.x + blockIdx.x * blockDim.x;
if(tx == 0){
for(int i=0;i<ITER;i++){
if (tx == 0) {
for (int i = 0; i < ITER; i++) {
Ad[tx] += 1;
}
}
}
int main(){
int A=0, *Ad;
int main() {
int A = 0, *Ad;
hipMalloc((void**)&Ad, SIZE);
hipMemcpy(Ad, &A, SIZE, hipMemcpyHostToDevice);
hipLaunchKernel(HIP_KERNEL_NAME(Iter), dim3(1), dim3(1), 0, 0, Ad);